{ pkgs, nix-config, ... }:

{

  home.packages = with pkgs; [
    appimage-run
    libappimage
    transmission_4-gtk
    wl-clipboard
    clipse
    maim
    wayland-utils
    libheif.out
    rpi-imager
    thonny
    freecad
    flatpak
    gst_all_1.gstreamer
    prusa-slicer
    via
    vial
    scribus
    pdfarranger
    tdf
    pdfchain
    pdftk
    zathura
    gpu-viewer

    wl-mirror

    soundconverter
    wmctrl

    godot_4
    gdtoolkit_4
    sane-airscan
    xsane

    nix-config.pkgs-stable.bitwarden-cli
    bitwarden-desktop
    tailscale
    trayscale
    font-manager

    squirreldisk
    papers
    newsflash

    stirling-pdf
    ripdrag

    sway-launcher-desktop
    swayosd

    thunderbird-latest
    emojify
    smile

    impression
    zoom-us
    nyxt
    ungoogled-chromium
    obsidian
    vlc
    polychromatic
    discord
    slack
    signal-desktop
    eyedropper
    onlyoffice-desktopeditors
    libreoffice
    hyphenDicts.en_US
    plex-mpv-shim
    plexamp
    plex-media-player

    switcheroo

    nix-config.pkgs-stable.blender
    davinci-resolve-studio
    steam
    processing
    zotero
    fractal
    handbrake
    krita
    rawtherapee
    inkscape
    gimp
    epsonscan2
    kicad
    turbocase
    openscad-unstable
    openscad-lsp
    picard
    evolutionWithPlugins
    plugdata
    pavucontrol
    qpwgraph
    helvum
    coppwr
    clapper
    ardour
    oculante
    farge
    halloy
    paleta
    wayback
    protonplus
    fstl

    wineWowPackages.stagingFull
    winetricks
  ];

  home.pointerCursor = {
    name = pkgs.rice.cursor.name;
    package = pkgs.bibata-cursors;
    size = 32;
    gtk.enable = true;
    x11.enable = true;
  };

  gtk = {
    enable = true;
    cursorTheme = {
      name = pkgs.rice.cursor.name;
      package = pkgs.bibata-cursors;
    };
    theme = {
      name = "Colloid-Dark";
      package = pkgs.colloid-gtk-theme.override {
          tweaks = [ "normal" "nord" ];
          themeVariants = [ "grey" ];

      };
    };
    iconTheme = {
      name = "Colloid";
      package = nix-config.pkgs-stable.colloid-icon-theme;
    };
  };

  qt = {
    enable = true;
    platformTheme.name = "gtk3";
    style = {
        package = pkgs.adwaita-qt;
        name = "adwaita-dark";
    };
  };

  fonts = {
    fontconfig = {
      enable = true;
    };
  };

  services.flatpak = {
    enable = true;
    packages = [
      "com.github.tchx84.Flatseal"
      "dev.qwery.AddWater"
    ];
  };

  programs = {
    # eww = {
    #   enable = true;
    #   configDir = ../../homes/emenel/dotfiles/dot_config/eww;
    # };
    firefox.enable = true;
  };

  xdg.configFile."halloy/config.toml".source =
    ../../homes/emenel/dotfiles/dot_config/halloy/config.toml;

}
